@@ -45,6 +45,17 @@ class Settings(DataObject):
 
 class Renderer:
 
+    @classmethod
+    def param(cls, name, required, regex, values, tip):
+        """ Experimental. Do not use. """
+        def decorator(method):
+            p = cls.Parameter(name, required, regex, values, tip)
+            if not hasattr(method, "parameters"):
+                method.parameters = []
+            method.parameters.append(p)
+            return method
+        return decorator
+
     @staticmethod
     def animated_audio_to_html(anim):
         return f"""<div>
